# Yitizi

[![](https://badge.fury.io/py/yitizi.svg)](https://pypi.org/project/yitizi/) [![](https://badge.fury.io/js/yitizi.svg)](https://www.npmjs.com/package/yitizi) [![](https://data.jsdelivr.com/v1/package/npm/yitizi/badge)](https://www.jsdelivr.com/package/npm/yitizi) [![](https://github.com/nk2028/yitizi/workflows/Package/badge.svg)](https://github.com/nk2028/yitizi/actions?query=workflow%3APackage)

Input a Chinese character. Output all the variant characters of it.<br>
輸入一個漢字，輸出它的全部異體字。<br>
输入一个汉字，输出它的全部异体字。

## Usage

### Python

```sh
pip install yitizi
```

```python
>>> import yitizi
>>> yitizi.get('和')
['咊', '龢']
```

### JavaScript (Node.js)

```sh
npm install yitizi
```

```javascript
> const Yitizi = require('yitizi');
> Yitizi.get('和');
[ '咊', '龢' ]
```

### JavaScript (browser)

```html
<script src="https://cdn.jsdelivr.net/npm/yitizi@0.0.3"></script>
```

```javascript
> Yitizi.get('和');
[ '咊', '龢' ]
```

## Design

To reduce data redundancy, only the orthodox-character-to-variant-characters mapping is stored in `yitizi.csv`:

![](https://raw.githubusercontent.com/nk2028/yitizi/7e605d3/demo/char.png)

The actual dictionary used by the library is `yitizi.json`, which is generated by the script `build/main.py` from `yitizi.csv`:

![](https://raw.githubusercontent.com/nk2028/yitizi/7e605d3/demo/route.png)

**Rule 1**: If specified in `yitizi.csv`, that _A_ is an orthodox character, and _B_ is its variant character, then:

- _A_ is variant character of _B_ in `yitizi.json`
- _B_ is variant character of _A_ in `yitizi.json`

**Rule 2**: If specified in `yitizi.csv`, that _A_ is an orthodox character, and _B<sub>1</sub>_, _B<sub>2</sub>_ are two of its variant characters, then:

- _B<sub>1</sub>_ is variant character of _B<sub>2</sub>_ in `yitizi.json`

For example, if we specify the following relationship in `yitizi.csv`:

![](https://raw.githubusercontent.com/nk2028/yitizi/7e605d3/demo/example1.png)

The generated `yitizi.json` would be:

![](https://raw.githubusercontent.com/nk2028/yitizi/7e605d3/demo/example2.png)

## Note for developers

You need to substitute all the occurrences of the version string before publishing a new release.
